.. redirect-from:: /users/prev_whats_new/github_stats_3.5.3

.. _github-stats-3-5-3:

GitHub statistics for 3.5.3 (Aug 10, 2022)
==========================================

GitHub statistics for 2022/05/03 (tag: v3.5.2) - 2022/08/10

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 19 issues and merged 66 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/71?closed=1>`__

The following 20 authors contributed 99 commits.

* Antony Lee
* Biswapriyo Nath
* David Gilbertson
* DWesl
* Elliott Sales de Andrade
* GavinZhang
* Greg Lucas
* Jody Klymak
* Kayran Schmidt
* Matthew Feickert
* Nickolaos Giannatos
* Oscar Gustafsson
* Ruth Comer
* SaumyaBhushan
* Scott Jones
* Scott Shambaugh
* tfpf
* Thomas A Caswell
* Tim Hoffmann
* wsykala

GitHub issues and pull requests:

Pull Requests (66):

* :ghpull:`23591`: Backport PR #23549 on branch v3.5.x (Don't clip colorbar dividers)
* :ghpull:`23593`: STY: Fix whitespace error from new flake8
* :ghpull:`23549`: Don't clip colorbar dividers
* :ghpull:`23528`: Backport PR #23523 on branch v3.5.x (TST: Update Quantity test class)
* :ghpull:`23523`: TST: Update Quantity test class
* :ghpull:`23508`: Add explicit registration of units in examples
* :ghpull:`23515`: Backport PR #23462: Fix AttributeError for pickle load of Figure class
* :ghpull:`23518`: Backport PR #23514 on branch v3.5.x (Fix doc build)
* :ghpull:`23517`: Backport PR #23511 on branch v3.5.x (supporting IBM i OS)
* :ghpull:`23511`: supporting IBM i OS
* :ghpull:`23462`: Fix AttributeError for pickle load of Figure class
* :ghpull:`23488`: Backport PR #23066 on branch v3.5.x (BLD: Define PyErr_SetFromWindowsErr on Cygwin.)
* :ghpull:`23066`: BLD: Define PyErr_SetFromWindowsErr on Cygwin.
* :ghpull:`23479`: Pin setuptools_scm on v3.5.x
* :ghpull:`22998`: Backport PR #22987 on branch v3.5.x (CI: bump test limit from tkagg on osx)
* :ghpull:`23478`: Backport PR #23476: FIX: reset to original DPI in getstate
* :ghpull:`23476`: FIX: reset to original DPI in getstate
* :ghpull:`23458`: Backport PR #23445 on branch v3.5.x (Compare thread native ids when checking whether running on main thread.)
* :ghpull:`23440`: Backport PR #23430 on branch v3.5.x (Fix divide by 0 runtime warning)
* :ghpull:`23430`: Fix divide by 0 runtime warning
* :ghpull:`23344`: Backport PR #23333: Fix errorbar handling of nan.
* :ghpull:`23333`: Fix errorbar handling of nan.
* :ghpull:`23338`: Backport PR #23278: Remove internal use of get/set dpi
* :ghpull:`23331`: Backport PR #22835 on branch v3.5.x (Fix BoundaryNorm cursor data output)
* :ghpull:`22835`: Fix BoundaryNorm cursor data output
* :ghpull:`23292`: Backport PR #23232 on branch v3.5.x (Fix passing stem markerfmt positionally when locs are not given)
* :ghpull:`23275`: Backport PR #23260 on branch v3.5.x (Fix Colorbar extend patches to have correct alpha)
* :ghpull:`23312`: Pin to an older pydata-sphinx-theme for v3.5.x
* :ghpull:`23278`: Remove internal use of get/set dpi
* :ghpull:`23232`: Fix passing stem markerfmt positionally when locs are not given
* :ghpull:`22865`: Fix issue with colorbar extend and drawedges
* :ghpull:`23260`: Fix Colorbar extend patches to have correct alpha
* :ghpull:`23245`: Backport PR #23144 on branch v3.5.x (Only import setuptools_scm when we are in a matplotlib git repo)
* :ghpull:`23144`: Only import setuptools_scm when we are in a matplotlib git repo
* :ghpull:`23242`: Backport PR #23203 on branch v3.5.x (Honour ``panchor`` keyword for colorbar on subplot)
* :ghpull:`23203`: Honour ``panchor`` keyword for colorbar on subplot
* :ghpull:`23228`: Backport PR #23209 on branch v3.5.x (Fix the vertical alignment of overunder symbols.)
* :ghpull:`23209`: Fix the vertical alignment of overunder symbols.
* :ghpull:`23184`: Backport PR #23174: Make sure SubFigure has _cachedRenderer
* :ghpull:`23194`: Backport PR #23095: Try to unbreak CI by xfailing OSX Tk tests
* :ghpull:`23113`: Backport PR #23057 and #23106
* :ghpull:`23185`: Backport PR #23168 on branch v3.5.x (Corrected docstring for artist.Artist.set_agg_filter)
* :ghpull:`23168`: Corrected docstring for artist.Artist.set_agg_filter
* :ghpull:`23174`: Make sure SubFigure has _cachedRenderer
* :ghpull:`23110`: Tweak subprocess_run_helper.
* :ghpull:`23138`: Backport PR #23137 on branch v3.5.x (DOC fix typo)
* :ghpull:`23137`: DOC fix typo
* :ghpull:`23125`: Backport PR #23122 on branch v3.5.x (Remove redundant rcparam default)
* :ghpull:`23120`: Backport PR #23115 on branch v3.5.x (DOC fixed duplicate/wrong default)
* :ghpull:`23095`: Try to unbreak CI by xfailing OSX Tk tests
* :ghpull:`23106`: Reuse subprocess_run_helper in test_pylab_integration.
* :ghpull:`23112`: Backport PR #23111 on branch v3.5.x (Fix _g_sig_digits for value<0 and delta=0.)
* :ghpull:`23111`: Fix _g_sig_digits for value<0 and delta=0.
* :ghpull:`23057`: FIX: ensure switching the backend installs repl hook
* :ghpull:`23075`: Backport PR #23069 on branch v3.5.x (TST: forgive more failures on pyside2 / pyside6 cross imports)
* :ghpull:`23069`: TST: forgive more failures on pyside2 / pyside6 cross imports
* :ghpull:`22981`: Backport PR #22979 on branch v3.5.x (Skip additional backend tests on import error)
* :ghpull:`23064`: Backport PR #22975 on branch v3.5.x (MNT: fix __array__ to numpy)
* :ghpull:`22975`: MNT: fix __array__ to numpy
* :ghpull:`23058`: Backport PR #23051 on branch v3.5.x (Fix variable initialization due to jump bypassing it)
* :ghpull:`23051`: Fix variable initialization due to jump bypassing it
* :ghpull:`23010`: Backport PR #23000 on branch v3.5.x (Additional details on VS install on installation page)
* :ghpull:`22995`: Backport PR #22994 on branch v3.5.x (Docs: ignore >>> on code prompts on documentation prompts)
* :ghpull:`23001`: CI: Add trivial pre-commit.ci config to avoid CI failure
* :ghpull:`22987`: CI: bump test limit from tkagg on osx
* :ghpull:`22979`: Skip additional backend tests on import error

Issues (19):

* :ghissue:`22864`: [Bug]: Colorbar with drawedges=True and extend='both' does not draw edges at extremities
* :ghissue:`23382`: [TST] Upcoming dependency test failures
* :ghissue:`23470`: [Bug]: fig.canvas.mpl_connect in 3.5.2 not registering events in jupyter lab unless using widget pan or zoom controls
* :ghissue:`22997`: [Bug]: Cygwin build fails due to use of Windows-only functions in _tkagg.cpp
* :ghissue:`23471`: [Bug]: DPI of a figure is doubled after unpickling on M1 Mac
* :ghissue:`23050`: [Doc]: Docstring for artist.Artist.set_agg_filter is incorrect
* :ghissue:`23307`: [Bug]: PEX warns about missing ``setuptools`` from ``install_requires`` in matplotlib
* :ghissue:`23330`: [Bug]: Missing values cause exception in errorbar plot
* :ghissue:`21915`: [Bug]: scalar mappable format_cursor_data crashes on BoundarNorm
* :ghissue:`22970`: [Bug]: Colorbar extend patches do not have correct alpha
* :ghissue:`23114`: [Bug]: matplotlib __init__.py checks for .git folder 2 levels up, then errors due to setup tools_scm
* :ghissue:`23157`: [Bug]: colorbar ignores keyword panchor=False
* :ghissue:`23229`: [Bug]: matplotlib==3.5.2 breaks ipywidgets
* :ghissue:`18085`: vertical alignment of \sum depends on the presence of subscripts and superscripts
* :ghissue:`23173`: [Bug]: Crash when adding clabels to subfigures
* :ghissue:`23108`: [Bug]: Imshow with all negative values leads to math domain errors.
* :ghissue:`23042`: [Bug]: Figures fail to redraw with IPython
* :ghissue:`23004`: [Bug]: test failure of test_cross_Qt_imports in 3.5.2
* :ghissue:`22973`: [Bug]: v3.5.2 causing plot to crash when plotting object with ``__array__`` method
